AcuRite - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# AcuRite

According to Acurite, the wind speed updates every 18 seconds. The wind direction updates every 30 seconds. Other sensors update every 60 seconds.

In fact, because of the message structure and the data logging design, these are the actual update frequencies:

AcuRite transmission periods
sensor | period
Wind speed | 18 seconds
Outdoor temperature, outdoor humidity | 36 seconds
Wind direction, rain total | 36 seconds
Indoor temperature, pressure | 60 seconds
Indoor humidity | 12 minutes (only when in USB mode 3)

The station emits partial packets, which may confuse some online services.

The AcuRite stations do not record wind gusts.

Some consoles have a small internal logger. Data in the logger are erased when power is removed from the station.

The console has a sensor for inside humidity, but the values from that sensor are available only by reading from the console logger. Due to instability of the console firmware, the WeeWX driver does not read the console logger.

## USB Mode

Some AcuRite consoles have a setting called "USB Mode" that controls how data are saved and communicated:

AcuRite USB mode
Mode | Show data in display | Store data in logger | Send data over USB
--- | --- | --- | ---
1 | yes | yes |
2 | yes |  |
3 | yes | yes | yes
4 | yes |  | yes

If the AcuRite console has multiple USB modes, it must be set to USB mode 3 or 4 in order to work with the WeeWX driver.

Communication via USB is disabled in modes 1 and 2. Mode 4 is more reliable than mode 3; mode 3 enables logging of data, mode 4 does not. When the console is logging it frequently causes USB communication problems.

The default mode is 2, so after a power failure one must use the console controls to change the mode before WeeWX can resume data collection.

The 01025, 01035, 01036, 01525, and 02032 consoles have a USB mode setting.

The 02064 and 01536 consoles do not have a mode setting; these consoles are always in USB mode 4.

## Configuring with `weectl device`

The `weectl device` utility cannot be used to configure AcuRite stations.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

AcuRite station data
Database Field | Observation | Loop | Archive
barometer |  | S |
pressure | pressure | H |
altimeter |  | S |
inTemp | temperature_in | H |
outTemp | temperature_out | H |
inHumidity | humidity_in |  |
outHumidity | humidity_out | H |
windSpeed | wind_speed | H |
windDir | wind_dir | H |
rain | rain | D |
| rain_total | H |
rainRate |  | S |
dewpoint |  | S |
windchill |  | S |
heatindex |  | S |
rxCheckPercent | rssi | H |
outTempBatteryStatus | battery | H |

Each packet contains a subset of all possible readings. For example, one type of packet contains windSpeed, windDir and rain. A different type of packet contains windSpeed, outTemp and outHumidity.

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service